@@ -379,7 +379,7 @@ class DatasetDrawer:
         else:
             # Render highest-dimension items last so coords are optically
             # aligned
-            for name, data in self._dataset.items():
+            for name, data in sorted(self._dataset.items()):
                 item = DrawerItem(name, data, config['colors']['data'])
                 # Using only x and 0d areas for 1-D dataset
                 if len(dims) == 1 or data.dims != dims:
@@ -403,7 +403,7 @@ class DatasetDrawer:
         else:
             categories = zip(['coords'], [ds.coords])
         for what, items in categories:
-            for name, var in items.items():
+            for name, var in sorted(items.items()):
                 item = DrawerItem(name, var, config['colors'][what])
                 if len(var.dims) == 0:
                     area_0d.append(item)
